<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Routing\MenuBuilder;

use Knp\Menu\MenuItem;
use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;

class LocationMenuBuilder implements \Chill\MainBundle\Routing\LocalMenuBuilderInterface
{
    private AuthorizationCheckerInterface $authorizationChecker;

    public function __construct(AuthorizationCheckerInterface $authorizationChecker)
    {
        $this->authorizationChecker = $authorizationChecker;
    }

    public function buildMenu($menuId, MenuItem $menu, array $parameters)
    {
        if (!$this->authorizationChecker->isGranted('ROLE_ADMIN')) {
            return;
        }

        $menu->addChild('Location type list', [
            'route' => 'chill_crud_main_location_type_index',
        ])->setExtras(['order' => 205]);

        $menu->addChild('Location list', [
            'route' => 'chill_crud_main_location_index',
        ])->setExtras(['order' => 206]);
    }

    public static function getMenuIds(): array
    {
        return ['admin_location'];
    }
}
